@@ -531,8 +531,6 @@ public:
     }
 };
 
-QQmlApplicationEngine* RScriptHandlerJs::mainEngine = NULL;
-
 
 RScriptHandlerJs::RScriptHandlerJs() : rjsapi(NULL), engine(NULL) {
 
@@ -645,14 +643,6 @@ void RScriptHandlerJs::init(bool main) {
     global.setProperty("qApp", engine->newQObject(app));
     QQmlEngine::setObjectOwnership(app, QQmlEngine::CppOwnership);
 
-    if (main) {
-        mainEngine = engine;
-    }
-    else {
-        global.setProperty("mainEngine", engine->newQObject(mainEngine));
-        QQmlEngine::setObjectOwnership(mainEngine, QQmlEngine::CppOwnership);
-    }
-
     /*
     {
         QString fileName = ":copyproperties.js";
