@@ -1109,11 +1109,12 @@ RArc.Ray = RArc_Wrapper.Ray;
         {
           //print("JS: RArc.createTangential");
           
-      if (arguments.length == 4) {
+      if (arguments.length >= 3 &&
+          arguments.length <= 5) {
     
                 // calling static wrapper:
                 return RArc_WrapperSingletonInstance.createTangential(
-                  arguments[0], arguments[1], arguments[2], arguments[3]
+                  arguments[0], arguments[1], arguments[2], arguments[3], arguments[4]
                 );
               
 
