@@ -1190,6 +1190,14 @@
           return this.__PROXY__.insertVertex(...args);
         };
     
+        // function 
+        RLeaderEntity.prototype.insertVertexAt = function(...args) 
+          
+        {
+          //print("JS: RLeaderEntity.prototype.insertVertexAt");
+          return this.__PROXY__.insertVertexAt(...args);
+        };
+    
         // function 
         RLeaderEntity.prototype.getVertexAt = function(...args) 
           
@@ -1254,6 +1262,14 @@
           return this.__PROXY__.setBulgeAt(...args);
         };
     
+        // function 
+        RLeaderEntity.prototype.getClosestSegment = function(...args) 
+          
+        {
+          //print("JS: RLeaderEntity.prototype.getClosestSegment");
+          return this.__PROXY__.getClosestSegment(...args);
+        };
+    
         // function 
         RLeaderEntity.prototype.getDirection1 = function(...args) 
           
